==> alsa-driver-1.0.16rc2.tar.bz2: alsa-driver-1.0.16rc2/pci/asihpi/hpicmn.h <==
/**

    AudioScience HPI driver
    Copyright (C) 1997-2003  AudioScience Inc. <support@audioscience.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of version 2 of the GNU General Public License as
    published by the Free Software Foundation;

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

struct hpi_adapter_obj {
	struct hpi_pci Pci;	/* PCI info - bus#,dev#,address etc */
	u16 wAdapterType;	/* ASI6701 etc */
	u16 wIndex;		/* */
	u16 wOpen;		/* =1 when adapter open */
	u16 wMixerOpen;

	struct hpios_spinlock dspLock;

	u16 wDspCrashed;
	u16 wHasControlCache;
	void *priv;
};

struct hpi_adapter_obj *FindAdapter(
	u16 wAdapterIndex
);
void WipeAdapterList(
	void
);
void SubSysGetAdapters(
	struct hpi_response *phr
);
u16 AddAdapter(
	struct hpi_adapter_obj *pao
);
void DeleteAdapter(
	struct hpi_adapter_obj *pao
);

short CheckControlCache(
	volatile struct hpi_control_cache_single *pC,
	struct hpi_message *phm,
	struct hpi_response *phr
);
void SyncControlCache(
	volatile struct hpi_control_cache_single *pC,
	struct hpi_message *phm,
	struct hpi_response *phr
);
u16 HpiValidateResponse(
	struct hpi_message *phm,
	struct hpi_response *phr
);

==> alsa-driver-1.0.17rc1.tar.bz2: alsa-driver-1.0.17rc1/pci/asihpi/hpicmn.h <==
/**

    AudioScience HPI driver
    Copyright (C) 1997-2003  AudioScience Inc. <support@audioscience.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of version 2 of the GNU General Public License as
    published by the Free Software Foundation;

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

struct hpi_adapter_obj {
	struct hpi_pci Pci;	/* PCI info - bus#,dev#,address etc */
	u16 wAdapterType;	/* ASI6701 etc */
	u16 wIndex;		/* */
	u16 wOpen;		/* =1 when adapter open */
	u16 wMixerOpen;

	struct hpios_spinlock dspLock;

	u16 wDspCrashed;
	u16 wHasControlCache;
	void *priv;
};

struct hpi_adapter_obj *HpiFindAdapter(
	u16 wAdapterIndex
);
u16 HpiAddAdapter(
	struct hpi_adapter_obj *pao
);

void HpiDeleteAdapter(
	struct hpi_adapter_obj *pao
);

short HpiCheckControlCache(
	struct hpi_control_cache_single *pC,
	struct hpi_message *phm,
	struct hpi_response *phr
);
void HpiSyncControlCache(
	struct hpi_control_cache_single *pC,
	struct hpi_message *phm,
	struct hpi_response *phr
);
u16 HpiValidateResponse(
	struct hpi_message *phm,
	struct hpi_response *phr
);
